import genanki
import pandas as pd


def create_model():
    my_model = genanki.Model(
      1607392319,
      'Simple Model',
      fields=[
        {'name': 'Question'},
        {'name': 'Answer'},
      ],
      templates=[
        {
          'name': 'Card 1',
          'qfmt': '{{Question}}',
          'afmt': '{{FrontSide}}<hr id="answer">{{Answer}}',
        },
      ])
    return my_model


def create_note(model, fields):
    note = genanki.Note(
        model=model,
        fields=fields
    )
    return note


def create_deck(name):
    deck = genanki.Deck(
      2059400110,
      name
    )
    return deck


def save_deck(deck, destination):
    my_package = genanki.Package(deck)
    # my_package.media_files = ['sound.mp3', 'images/image.jpg']
    my_package.write_to_file(destination)


def load_csv(path):
    df = pd.read_csv(path, header=None)
    return df


def add_df_to_deck(df: pd.DataFrame, deck: genanki.Deck):
    model = create_model()
    for x in df.to_dict('records'):
        note = create_note(model, fields=(x[2], x[3]))
        deck.add_note(note)
    return deck


def basic_pandas_to_anki(csv_path, output_path, name):
    df = load_csv(csv_path)
    deck = create_deck(name)
    add_df_to_deck(df, deck)
    save_deck(deck, output_path)
